@@ -1,4 +1,5 @@
-__all__ = ['ddtask', 'status', 'initialize']
+__version__ = '0.0.5.1'
+
 
 import win32api
 import win32con
@@ -9,6 +10,11 @@ import string
 import cv2
 import numpy as np
 import re
+import os
 
+from ctypes import windll
 from threading import Thread
 
+from .dl_script import load_onnx, build_preprocess, build_postprocess
+
+VkKeyScanA = windll.user32.VkKeyScanA
